pub enum PreviewError {
Cache,
Nsfw,
Permission,
SerenityError(Error),
}Expand description
Errors that can occur when generating a Discord message preview.
Variants
Cache
Failed to retrieve channel information from cache.
Nsfw
The target channel is marked as NSFW.
Permission
The target channel is private or a private thread.
SerenityError(Error)
An error occurred while communicating with Discord.